turbogears.widgets.meta.MetaWidget

turbogears :: widgets :: meta :: MetaWidget :: Class MetaWidget |
[hide private]

# Type MetaWidget

    object --+
             |
          type --+
                 |
                MetaWidget

Known Subclasses:
  base.MetaDescription

Instance Methods | [hide private]
__init__(cls, name, bases, dct) x.__init__(...) initializes x; see x.__class__.__doc__ for signature |
Inherited from `type`: `__call__`, `__cmp__`, `__delattr__`, `__getattribute__`, `__hash__`, `__repr__`, `__setattr__`, `__subclasses__`, `mro` Inherited from `object`: `__reduce__`, `__reduce_ex__`, `__str__`

Static Methods | [hide private]
__new__(cls, name, bases, dct) Returns: a new object with type S, a subtype of T |

Properties | [hide private]
Inherited from `type`: `__base__`, `__bases__`, `__basicsize__`, `__dictoffset__`, `__flags__`, `__itemsize__`, `__mro__`, `__name__`, `__weakrefoffset__` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(cls, name, bases, dct) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __new__(cls, name, bases, dct) Static Method |
  Returns:
      a new object with type S, a subtype of T
Overrides: type.__new__ (inherited documentation)